==> jc-1.4.0.tar.gz: javax/naming/event/NamingEvent.h <==
// public class javax.naming.event.NamingEvent

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject
// @dep_class 58062d83268743f3 javax_naming_event_NamingEvent

// header file dependencies
// @dep_header java_util_EventObject

#include "java/util/EventObject.h"

#ifndef _JC_javax_naming_event_NamingEvent_H_
#define _JC_javax_naming_event_NamingEvent_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_javax_naming_Binding$object;
struct _jc_javax_naming_event_EventContext$object;
struct _jc_javax_naming_event_NamingListener$object;

// Typedefs
typedef struct _jc_javax_naming_event_NamingEvent$sub_refs	_jc_javax_naming_event_NamingEvent$sub_refs;
typedef struct _jc_javax_naming_event_NamingEvent$sub_nonrefs	_jc_javax_naming_event_NamingEvent$sub_nonrefs;
typedef struct _jc_javax_naming_event_NamingEvent$refs	_jc_javax_naming_event_NamingEvent$refs;
typedef struct _jc_javax_naming_event_NamingEvent$nonrefs	_jc_javax_naming_event_NamingEvent$nonrefs;
typedef struct _jc_javax_naming_event_NamingEvent$object	_jc_javax_naming_event_NamingEvent$object;

typedef struct _jc_javax_naming_event_NamingEvent$fields_struct	_jc_javax_naming_event_NamingEvent$fields_struct;
typedef const struct _jc_javax_naming_event_NamingEvent$vmethods	_jc_javax_naming_event_NamingEvent$vmethods;
typedef const struct _jc_javax_naming_event_NamingEvent$vtable	_jc_javax_naming_event_NamingEvent$vtable;
typedef const struct _jc_javax_naming_event_NamingEvent$vtype	_jc_javax_naming_event_NamingEvent$vtype;

// Class fields structure
struct _jc_javax_naming_event_NamingEvent$fields_struct {
	jint	OBJECT__5fADDED;
	jint	OBJECT__5fCHANGED;
	jint	OBJECT__5fREMOVED;
	jint	OBJECT__5fRENAMED;
};
extern _jc_javax_naming_event_NamingEvent$fields_struct _jc_javax_naming_event_NamingEvent$class_fields;

// Constructors
extern void _jc_javax_naming_event_NamingEvent$method$_init$db88878bdfbb13ec(_jc_env *, struct _jc_javax_naming_event_NamingEvent$object *, struct _jc_object *, jint, struct _jc_javax_naming_Binding$object *, struct _jc_javax_naming_Binding$object *, struct _jc_java_lang_Object$object *);

// Virtual methods
extern void _jc_javax_naming_event_NamingEvent$method$dispatch$3a7ef28658c9ea97(_jc_env *, struct _jc_javax_naming_event_NamingEvent$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_javax_naming_event_NamingEvent$method$getChangeInfo$58107c253b871422(_jc_env *, struct _jc_javax_naming_event_NamingEvent$object *);
extern struct _jc_object *_jc_javax_naming_event_NamingEvent$method$getEventContext$4d00ee253e16f306(_jc_env *, struct _jc_javax_naming_event_NamingEvent$object *);
extern struct _jc_javax_naming_Binding$object *_jc_javax_naming_event_NamingEvent$method$getNewBinding$9f80f2293044322d(_jc_env *, struct _jc_javax_naming_event_NamingEvent$object *);
extern struct _jc_javax_naming_Binding$object *_jc_javax_naming_event_NamingEvent$method$getOldBinding$a2f6f7d186ea1137(_jc_env *, struct _jc_javax_naming_event_NamingEvent$object *);
extern jint _jc_javax_naming_event_NamingEvent$method$getType$74c20eac6b18d047(_jc_env *, struct _jc_javax_naming_event_NamingEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_naming_event_NamingEvent$method_info$dispatch$3a7ef28658c9ea97;
extern _jc_method _jc_javax_naming_event_NamingEvent$method_info$getChangeInfo$58107c253b871422;
extern _jc_method _jc_javax_naming_event_NamingEvent$method_info$getEventContext$4d00ee253e16f306;
extern _jc_method _jc_javax_naming_event_NamingEvent$method_info$getNewBinding$9f80f2293044322d;
extern _jc_method _jc_javax_naming_event_NamingEvent$method_info$getOldBinding$a2f6f7d186ea1137;
extern _jc_method _jc_javax_naming_event_NamingEvent$method_info$getType$74c20eac6b18d047;

// Virtual methods structure
struct _jc_javax_naming_event_NamingEvent$vmethods {
	void	(*dispatch$3a7ef28658c9ea97)(_jc_env *, struct _jc_javax_naming_event_NamingEvent$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*getChangeInfo$58107c253b871422)(_jc_env *, struct _jc_javax_naming_event_NamingEvent$object *);
	struct _jc_object	*(*getEventContext$4d00ee253e16f306)(_jc_env *, struct _jc_javax_naming_event_NamingEvent$object *);
	struct _jc_javax_naming_Binding$object	*(*getNewBinding$9f80f2293044322d)(_jc_env *, struct _jc_javax_naming_event_NamingEvent$object *);
	struct _jc_javax_naming_Binding$object	*(*getOldBinding$a2f6f7d186ea1137)(_jc_env *, struct _jc_javax_naming_event_NamingEvent$object *);
	jint	(*getType$74c20eac6b18d047)(_jc_env *, struct _jc_javax_naming_event_NamingEvent$object *);
};

// Vtable
struct _jc_javax_naming_event_NamingEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_javax_naming_event_NamingEvent$vmethods	javax_naming_event_NamingEvent;
};

// Vtype
struct _jc_javax_naming_event_NamingEvent$vtype {
	_jc_type			type;
	_jc_javax_naming_event_NamingEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_naming_event_NamingEvent$sub_refs {
	struct _jc_java_lang_Object$object	*changeInfo;
	struct _jc_javax_naming_Binding$object	*oldBinding;
	struct _jc_javax_naming_Binding$object	*newBinding;
};

// Reference instance fields (object)
struct _jc_javax_naming_event_NamingEvent$refs {
    _jc_javax_naming_event_NamingEvent$sub_refs	javax_naming_event_NamingEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_naming_event_NamingEvent$sub_nonrefs {
	jint	type;
};

// Non-reference instance fields (object)
struct _jc_javax_naming_event_NamingEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_javax_naming_event_NamingEvent$sub_nonrefs	javax_naming_event_NamingEvent;
};

// Object instance structure
struct _jc_javax_naming_event_NamingEvent$object {
	_jc_javax_naming_event_NamingEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_naming_event_NamingEvent$vtype	*vtype;
	_jc_javax_naming_event_NamingEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_naming_event_NamingEvent$vtype _jc_javax_naming_event_NamingEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_naming_event_NamingEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_naming_event_NamingEvent$class_object;

#endif	/* _JC_javax_naming_event_NamingEvent_H_ */

==> jc-1.4.6.tar.gz: javax/naming/event/NamingEvent.h <==
// public class javax.naming.event.NamingEvent

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject
// @dep_class 58062d83268743f3 javax_naming_event_NamingEvent

// header file dependencies
// @dep_header java_util_EventObject

#include "java/util/EventObject.h"

#ifndef _JC_javax_naming_event_NamingEvent_H_
#define _JC_javax_naming_event_NamingEvent_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_javax_naming_Binding$object;
struct _jc_javax_naming_event_EventContext$object;
struct _jc_javax_naming_event_NamingListener$object;

// Typedefs
typedef struct _jc_javax_naming_event_NamingEvent$sub_refs	_jc_javax_naming_event_NamingEvent$sub_refs;
typedef struct _jc_javax_naming_event_NamingEvent$sub_nonrefs	_jc_javax_naming_event_NamingEvent$sub_nonrefs;
typedef struct _jc_javax_naming_event_NamingEvent$refs	_jc_javax_naming_event_NamingEvent$refs;
typedef struct _jc_javax_naming_event_NamingEvent$nonrefs	_jc_javax_naming_event_NamingEvent$nonrefs;
typedef struct _jc_javax_naming_event_NamingEvent$object	_jc_javax_naming_event_NamingEvent$object;

typedef struct _jc_javax_naming_event_NamingEvent$fields_struct	_jc_javax_naming_event_NamingEvent$fields_struct;
typedef const struct _jc_javax_naming_event_NamingEvent$vmethods	_jc_javax_naming_event_NamingEvent$vmethods;
typedef const struct _jc_javax_naming_event_NamingEvent$vtable	_jc_javax_naming_event_NamingEvent$vtable;
typedef const struct _jc_javax_naming_event_NamingEvent$vtype	_jc_javax_naming_event_NamingEvent$vtype;

// Class fields structure
struct _jc_javax_naming_event_NamingEvent$fields_struct {
	jint	OBJECT__5fADDED;
	jint	OBJECT__5fCHANGED;
	jint	OBJECT__5fREMOVED;
	jint	OBJECT__5fRENAMED;
};
extern _jc_javax_naming_event_NamingEvent$fields_struct _jc_javax_naming_event_NamingEvent$class_fields;

// Constructors
extern void _jc_javax_naming_event_NamingEvent$method$_init$db88878bdfbb13ec(_jc_env *, struct _jc_javax_naming_event_NamingEvent$object *, struct _jc_object *, jint, struct _jc_javax_naming_Binding$object *, struct _jc_javax_naming_Binding$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_naming_event_NamingEvent$method$dispatch$3a7ef28658c9ea97(_jc_env *, struct _jc_javax_naming_event_NamingEvent$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_javax_naming_event_NamingEvent$method$getChangeInfo$58107c253b871422(_jc_env *, struct _jc_javax_naming_event_NamingEvent$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_naming_event_NamingEvent$method$getEventContext$4d00ee253e16f306(_jc_env *, struct _jc_javax_naming_event_NamingEvent$object *) _JC_JCNI_ATTR;
extern struct _jc_javax_naming_Binding$object *_jc_javax_naming_event_NamingEvent$method$getNewBinding$9f80f2293044322d(_jc_env *, struct _jc_javax_naming_event_NamingEvent$object *) _JC_JCNI_ATTR;
extern struct _jc_javax_naming_Binding$object *_jc_javax_naming_event_NamingEvent$method$getOldBinding$a2f6f7d186ea1137(_jc_env *, struct _jc_javax_naming_event_NamingEvent$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_naming_event_NamingEvent$method$getType$74c20eac6b18d047(_jc_env *, struct _jc_javax_naming_event_NamingEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_naming_event_NamingEvent$method_info$dispatch$3a7ef28658c9ea97;
extern _jc_method _jc_javax_naming_event_NamingEvent$method_info$getChangeInfo$58107c253b871422;
extern _jc_method _jc_javax_naming_event_NamingEvent$method_info$getEventContext$4d00ee253e16f306;
extern _jc_method _jc_javax_naming_event_NamingEvent$method_info$getNewBinding$9f80f2293044322d;
extern _jc_method _jc_javax_naming_event_NamingEvent$method_info$getOldBinding$a2f6f7d186ea1137;
extern _jc_method _jc_javax_naming_event_NamingEvent$method_info$getType$74c20eac6b18d047;

// Virtual methods structure
struct _jc_javax_naming_event_NamingEvent$vmethods {
	void	(*dispatch$3a7ef28658c9ea97)(_jc_env *, struct _jc_javax_naming_event_NamingEvent$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*getChangeInfo$58107c253b871422)(_jc_env *, struct _jc_javax_naming_event_NamingEvent$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getEventContext$4d00ee253e16f306)(_jc_env *, struct _jc_javax_naming_event_NamingEvent$object *) _JC_JCNI_ATTR;
	struct _jc_javax_naming_Binding$object	*(*getNewBinding$9f80f2293044322d)(_jc_env *, struct _jc_javax_naming_event_NamingEvent$object *) _JC_JCNI_ATTR;
	struct _jc_javax_naming_Binding$object	*(*getOldBinding$a2f6f7d186ea1137)(_jc_env *, struct _jc_javax_naming_event_NamingEvent$object *) _JC_JCNI_ATTR;
	jint	(*getType$74c20eac6b18d047)(_jc_env *, struct _jc_javax_naming_event_NamingEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_naming_event_NamingEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_javax_naming_event_NamingEvent$vmethods	javax_naming_event_NamingEvent;
};

// Vtype
struct _jc_javax_naming_event_NamingEvent$vtype {
	_jc_type			type;
	_jc_javax_naming_event_NamingEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_naming_event_NamingEvent$sub_refs {
	struct _jc_java_lang_Object$object	*changeInfo;
	struct _jc_javax_naming_Binding$object	*oldBinding;
	struct _jc_javax_naming_Binding$object	*newBinding;
};

// Reference instance fields (object)
struct _jc_javax_naming_event_NamingEvent$refs {
    _jc_javax_naming_event_NamingEvent$sub_refs	javax_naming_event_NamingEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_naming_event_NamingEvent$sub_nonrefs {
	jint	type;
};

// Non-reference instance fields (object)
struct _jc_javax_naming_event_NamingEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_javax_naming_event_NamingEvent$sub_nonrefs	javax_naming_event_NamingEvent;
};

// Object instance structure
struct _jc_javax_naming_event_NamingEvent$object {
	_jc_javax_naming_event_NamingEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_naming_event_NamingEvent$vtype	*vtype;
	_jc_javax_naming_event_NamingEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_naming_event_NamingEvent$vtype _jc_javax_naming_event_NamingEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_naming_event_NamingEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_naming_event_NamingEvent$class_object;

#endif	/* _JC_javax_naming_event_NamingEvent_H_ */
